@@ -35,7 +35,7 @@ your system.
 
 use XSLoader;
 
-our $VERSION = '0.12_91';
+our $VERSION = '0.13_90';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -272,13 +272,14 @@ building this library. (Hopefully these will eventually merge into QuickJS.)
 
 =head1 LIBATOMIC
 
-As of this writing, on RaspiOS this library has to link to libatomic
-in order to avoid runtime linker errors.
+QuickJS uses C11 atomics. Most platforms implement that functionality in
+hardware, but others (e.g., arm32) don’t. To fill that void, we need to link
+to libatomic.
 
-To avoid this problem in a portable manner, this library’s F<Makefile.PL>
-tries to detect whether libatomic is necessary and will only link if needed.
-If, for some reason, you need manual control over that linking, set
-C<JS_QUICKJS_LINK_LIBATOMIC> in the environment to 1 or a falsy value.
+This library’s build logic detects whether libatomic is necessary and will
+only link to it if needed. If, for some reason, you need manual control over
+that linking, set C<JS_QUICKJS_LINK_LIBATOMIC> in the environment to 1 or a
+falsy value.
 
 If you don’t know what any of that means, you can probably ignore it.
 
